@@ -124,6 +124,6 @@ class utility:
                 Private_Ip = gatewayAddressess[0]['PrivateIp']
                 Public_Ip = gatewayAddressess[0]['PublicIp']
                 natgatewayid = i['NatGatewayId']
-                data=[natgatewayid['NatGatewayId'],state['State'],Allocation_id['Allocation_Id'],NetworkInterfaceId['Network_Interface_Id'],Private_Ip['Private_IP'],Public_Ip['Public_IP']]
+                data=[natgatewayid,state,Allocation_id,NetworkInterfaceId,Private_Ip,Public_Ip]
                 writer.writerow(data)
 
